@@ -4,8 +4,8 @@ import (
 	"errors"
 	"testing"
 
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/hashicorp/go-multierror"
 	"github.com/stretchr/testify/require"
 )
@@ -15,7 +15,7 @@ func TestDescription(t *testing.T) {
 }
 
 func TestAnnounce(t *testing.T) {
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Announce: config.Announce{
 			Twitter: config.Twitter{
 				Enabled: true,
@@ -34,48 +34,53 @@ func TestAnnounce(t *testing.T) {
 }
 
 func TestAnnounceAllDisabled(t *testing.T) {
-	ctx := context.New(config.Project{})
+	ctx := testctx.New()
 	require.NoError(t, Pipe{}.Run(ctx))
 }
 
 func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
-		ctx := context.New(config.Project{})
-		ctx.SkipAnnounce = true
-		require.True(t, Pipe{}.Skip(ctx))
+		ctx := testctx.New(testctx.SkipAnnounce)
+		b, err := Pipe{}.Skip(ctx)
+		require.NoError(t, err)
+		require.True(t, b)
 	})
 
 	t.Run("skip on patches", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Announce: config.Announce{
 				Skip: "{{gt .Patch 0}}",
 			},
-		})
-		ctx.Semver.Patch = 1
-		require.True(t, Pipe{}.Skip(ctx))
+		}, testctx.WithSemver(0, 0, 1, ""))
+		b, err := Pipe{}.Skip(ctx)
+		require.NoError(t, err)
+		require.True(t, b)
 	})
 
-	t.Run("skip on invalid template", func(t *testing.T) {
-		ctx := context.New(config.Project{
+	t.Run("invalid template", func(t *testing.T) {
+		ctx := testctx.NewWithCfg(config.Project{
 			Announce: config.Announce{
 				Skip: "{{if eq .Patch 123}",
 			},
-		})
-		ctx.Semver.Patch = 1
-		require.True(t, Pipe{}.Skip(ctx))
+		}, testctx.WithSemver(0, 0, 1, ""))
+		_, err := Pipe{}.Skip(ctx)
+		require.Error(t, err)
 	})
 
 	t.Run("dont skip", func(t *testing.T) {
-		require.False(t, Pipe{}.Skip(context.New(config.Project{})))
+		b, err := Pipe{}.Skip(testctx.New())
+		require.NoError(t, err)
+		require.False(t, b)
 	})
 
 	t.Run("dont skip based on template", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Announce: config.Announce{
 				Skip: "{{gt .Patch 0}}",
 			},
 		})
-		ctx.Semver.Patch = 0
-		require.False(t, Pipe{}.Skip(ctx))
+		b, err := Pipe{}.Skip(ctx)
+		require.NoError(t, err)
+		require.False(t, b)
 	})
 }
