@@ -12,6 +12,7 @@ import (
 	"github.com/goreleaser/goreleaser/internal/client"
 	"github.com/goreleaser/goreleaser/internal/git"
 	"github.com/goreleaser/goreleaser/internal/golden"
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
@@ -33,6 +34,10 @@ func createTemplateData() templateData {
 		Rel:        "1",
 		Provides:   []string{"test"},
 		OptDepends: []string{"nfpm"},
+		Backup: []string{
+			"/etc/mypkg.conf",
+			"/var/share/mypkg",
+		},
 		Maintainers: []string{
 			"Ciclano <ciclano@example.com>",
 			"Cicrano <cicrano@example.com>",
@@ -96,7 +101,7 @@ func createTemplateData() templateData {
 
 func TestFullAur(t *testing.T) {
 	data := createTemplateData()
-	pkg, err := applyTemplate(context.New(config.Project{
+	pkg, err := applyTemplate(testctx.NewWithCfg(config.Project{
 		ProjectName: "foo",
 	}), aurTemplateData, data)
 	require.NoError(t, err)
@@ -105,7 +110,7 @@ func TestFullAur(t *testing.T) {
 }
 
 func TestAurSimple(t *testing.T) {
-	pkg, err := applyTemplate(context.New(config.Project{}), aurTemplateData, createTemplateData())
+	pkg, err := applyTemplate(testctx.New(), aurTemplateData, createTemplateData())
 	require.NoError(t, err)
 	require.Contains(t, pkg, `# Maintainer: Ciclano <ciclano@example.com>`)
 	require.Contains(t, pkg, `# Maintainer: Cicrano <cicrano@example.com>`)
@@ -121,7 +126,7 @@ func TestAurSimple(t *testing.T) {
 func TestFullSrcInfo(t *testing.T) {
 	data := createTemplateData()
 	data.License = "MIT"
-	pkg, err := applyTemplate(context.New(config.Project{
+	pkg, err := applyTemplate(testctx.NewWithCfg(config.Project{
 		ProjectName: "foo",
 	}), srcInfoTemplate, data)
 	require.NoError(t, err)
@@ -130,7 +135,7 @@ func TestFullSrcInfo(t *testing.T) {
 }
 
 func TestSrcInfoSimple(t *testing.T) {
-	pkg, err := applyTemplate(context.New(config.Project{}), srcInfoTemplate, createTemplateData())
+	pkg, err := applyTemplate(testctx.New(), srcInfoTemplate, createTemplateData())
 	require.NoError(t, err)
 	require.Contains(t, pkg, `pkgbase = test-bin`)
 	require.Contains(t, pkg, `pkgname = test-bin`)
@@ -142,9 +147,10 @@ func TestSrcInfoSimple(t *testing.T) {
 
 func TestFullPipe(t *testing.T) {
 	type testcase struct {
-		prepare              func(ctx *context.Context)
-		expectedRunError     string
-		expectedPublishError string
+		prepare                func(ctx *context.Context)
+		expectedRunError       string
+		expectedPublishError   string
+		expectedPublishErrorIs error
 	}
 	for name, tt := range map[string]testcase{
 		"default": {
@@ -205,7 +211,7 @@ func TestFullPipe(t *testing.T) {
 			prepare: func(ctx *context.Context) {
 				ctx.Config.AURs[0].PrivateKey = "testdata/nope"
 			},
-			expectedPublishError: `could not stat aur.private_key: stat testdata/nope: no such file or directory`,
+			expectedPublishErrorIs: os.ErrNotExist,
 		},
 		"invalid-git-url-template": {
 			prepare: func(ctx *context.Context) {
@@ -234,36 +240,29 @@ func TestFullPipe(t *testing.T) {
 	} {
 		t.Run(name, func(t *testing.T) {
 			url := makeBareRepo(t)
-			key := makeKey(t, keygen.Ed25519)
+			key := makeKey(t, keygen.Ed25519, nil)
 
 			folder := t.TempDir()
-			ctx := context.New(config.Project{
-				Dist:        folder,
-				ProjectName: name,
-				AURs: []config.AUR{
-					{
-						Name:        name,
-						IDs:         []string{"foo"},
-						PrivateKey:  key,
-						License:     "MIT",
-						GitURL:      url,
-						Description: "A run pipe test fish food and FOO={{ .Env.FOO }}",
+			ctx := testctx.NewWithCfg(
+				config.Project{
+					Dist:        folder,
+					ProjectName: name,
+					AURs: []config.AUR{
+						{
+							Name:        name,
+							IDs:         []string{"foo"},
+							PrivateKey:  key,
+							License:     "MIT",
+							GitURL:      url,
+							Description: "A run pipe test fish food and FOO={{ .Env.FOO }}",
+						},
 					},
+					Env: []string{"FOO=foo_is_bar"},
 				},
-			})
-			ctx.Git = context.GitInfo{
-				CurrentTag: "v1.0.1-foo",
-			}
-			ctx.Semver = context.Semver{
-				Major:      1,
-				Minor:      0,
-				Patch:      1,
-				Prerelease: "foo",
-			}
-			ctx.Version = "1.0.1-foo"
-			ctx.Env = map[string]string{
-				"FOO": "foo_is_bar",
-			}
+				testctx.WithCurrentTag("v1.0.1-foo"),
+				testctx.WithSemver(1, 0, 1, "foo"),
+				testctx.WithVersion("1.0.1-foo"),
+			)
 
 			tt.prepare(ctx)
 			ctx.Artifacts.Add(&artifact.Artifact{
@@ -324,6 +323,12 @@ func TestFullPipe(t *testing.T) {
 				require.EqualError(t, Pipe{}.Publish(ctx), tt.expectedPublishError)
 				return
 			}
+
+			if tt.expectedPublishErrorIs != nil {
+				require.ErrorIs(t, Pipe{}.Publish(ctx), tt.expectedPublishErrorIs)
+				return
+			}
+
 			require.NoError(t, Pipe{}.Publish(ctx))
 
 			requireEqualRepoFiles(t, folder, name, url)
@@ -333,47 +338,39 @@ func TestFullPipe(t *testing.T) {
 
 func TestRunPipe(t *testing.T) {
 	url := makeBareRepo(t)
-	key := makeKey(t, keygen.Ed25519)
+	key := makeKey(t, keygen.Ed25519, nil)
 
 	folder := t.TempDir()
-	ctx := context.New(config.Project{
-		Dist:        folder,
-		ProjectName: "foo",
-		AURs: []config.AUR{
-			{
-				License:     "MIT",
-				Description: "A run pipe test aur and FOO={{ .Env.FOO }}",
-				Homepage:    "https://github.com/goreleaser",
-				IDs:         []string{"foo"},
-				GitURL:      url,
-				PrivateKey:  key,
+	ctx := testctx.NewWithCfg(
+		config.Project{
+			Dist:        folder,
+			ProjectName: "foo",
+			AURs: []config.AUR{
+				{
+					License:     "MIT",
+					Description: "A run pipe test aur and FOO={{ .Env.FOO }}",
+					Homepage:    "https://github.com/goreleaser",
+					IDs:         []string{"foo"},
+					GitURL:      url,
+					PrivateKey:  key,
+				},
 			},
-		},
-		GitHubURLs: config.GitHubURLs{
-			Download: "https://github.com",
-		},
-		Release: config.Release{
-			GitHub: config.Repo{
-				Owner: "test",
-				Name:  "test",
+			GitHubURLs: config.GitHubURLs{
+				Download: "https://github.com",
 			},
+			Release: config.Release{
+				GitHub: config.Repo{
+					Owner: "test",
+					Name:  "test",
+				},
+			},
+			Env: []string{"FOO=foo_is_bar"},
 		},
-	})
-
-	ctx.TokenType = context.TokenTypeGitHub
-	ctx.Git = context.GitInfo{
-		CurrentTag: "v1.0.1",
-	}
-	ctx.Semver = context.Semver{
-		Major: 1,
-		Minor: 0,
-		Patch: 1,
-	}
-	ctx.Version = "1.0.1"
-	ctx.Artifacts = artifact.New()
-	ctx.Env = map[string]string{
-		"FOO": "foo_is_bar",
-	}
+		testctx.GitHubTokenType,
+		testctx.WithCurrentTag("v1.0.1"),
+		testctx.WithSemver(1, 0, 1, ""),
+		testctx.WithVersion("1.0.1"),
+	)
 
 	for _, a := range []struct {
 		name   string
@@ -465,13 +462,10 @@ func TestRunPipe(t *testing.T) {
 }
 
 func TestRunPipeNoBuilds(t *testing.T) {
-	ctx := context.New(
-		config.Project{
-			ProjectName: "foo",
-			AURs:        []config.AUR{{}},
-		},
-	)
-	ctx.TokenType = context.TokenTypeGitHub
+	ctx := testctx.NewWithCfg(config.Project{
+		ProjectName: "foo",
+		AURs:        []config.AUR{{}},
+	}, testctx.GitHubTokenType)
 	client := client.NewMock()
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.Equal(t, ErrNoArchivesFound, runAll(ctx, client))
@@ -480,26 +474,21 @@ func TestRunPipeNoBuilds(t *testing.T) {
 
 func TestRunPipeBinaryRelease(t *testing.T) {
 	url := makeBareRepo(t)
-	key := makeKey(t, keygen.Ed25519)
+	key := makeKey(t, keygen.Ed25519, nil)
 	folder := t.TempDir()
-	ctx := context.New(config.Project{
-		Dist:        folder,
-		ProjectName: "foo",
-		AURs: []config.AUR{{
-			GitURL:     url,
-			PrivateKey: key,
-		}},
-	})
-
-	ctx.Git = context.GitInfo{
-		CurrentTag: "v1.2.1",
-	}
-	ctx.Semver = context.Semver{
-		Major: 1,
-		Minor: 2,
-		Patch: 1,
-	}
-	ctx.Version = "1.2.1"
+	ctx := testctx.NewWithCfg(
+		config.Project{
+			Dist:        folder,
+			ProjectName: "foo",
+			AURs: []config.AUR{{
+				GitURL:     url,
+				PrivateKey: key,
+			}},
+		},
+		testctx.WithVersion("1.2.1"),
+		testctx.WithCurrentTag("v1.2.1"),
+		testctx.WithSemver(1, 2, 1, ""),
+	)
 
 	path := filepath.Join(folder, "dist/foo_linux_amd64/foo")
 	ctx.Artifacts.Add(&artifact.Artifact{
@@ -531,19 +520,17 @@ func TestRunPipeBinaryRelease(t *testing.T) {
 
 func TestRunPipeNoUpload(t *testing.T) {
 	folder := t.TempDir()
-	ctx := context.New(config.Project{
-		Dist:        folder,
-		ProjectName: "foo",
-		Release:     config.Release{},
-		AURs:        []config.AUR{{}},
-	})
-	ctx.TokenType = context.TokenTypeGitHub
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.1"}
-	ctx.Semver = context.Semver{
-		Major: 1,
-		Minor: 0,
-		Patch: 1,
-	}
+	ctx := testctx.NewWithCfg(
+		config.Project{
+			Dist:        folder,
+			ProjectName: "foo",
+			Release:     config.Release{},
+			AURs:        []config.AUR{{}},
+		},
+		testctx.GitHubTokenType,
+		testctx.WithCurrentTag("v1.0.1"),
+		testctx.WithSemver(1, 0, 1, ""),
+	)
 
 	path := filepath.Join(folder, "whatever.tar.gz")
 	f, err := os.Create(path)
@@ -586,20 +573,18 @@ func TestRunPipeNoUpload(t *testing.T) {
 
 func TestRunEmptyTokenType(t *testing.T) {
 	folder := t.TempDir()
-	ctx := context.New(config.Project{
-		Dist:        folder,
-		ProjectName: "foo",
-		Release:     config.Release{},
-		AURs: []config.AUR{
-			{},
+	ctx := testctx.NewWithCfg(
+		config.Project{
+			Dist:        folder,
+			ProjectName: "foo",
+			Release:     config.Release{},
+			AURs: []config.AUR{
+				{},
+			},
 		},
-	})
-	ctx.Git = context.GitInfo{CurrentTag: "v1.0.1"}
-	ctx.Semver = context.Semver{
-		Major: 1,
-		Minor: 0,
-		Patch: 1,
-	}
+		testctx.WithGitInfo(context.GitInfo{CurrentTag: "v1.0.1"}),
+		testctx.WithSemver(1, 0, 1, ""),
+	)
 	path := filepath.Join(folder, "whatever.tar.gz")
 	f, err := os.Create(path)
 	require.NoError(t, err)
@@ -622,15 +607,10 @@ func TestRunEmptyTokenType(t *testing.T) {
 
 func TestDefault(t *testing.T) {
 	t.Run("empty", func(t *testing.T) {
-		ctx := &context.Context{
-			TokenType: context.TokenTypeGitHub,
-			Config: config.Project{
-				ProjectName: "myproject",
-				AURs: []config.AUR{
-					{},
-				},
-			},
-		}
+		ctx := testctx.NewWithCfg(config.Project{
+			ProjectName: "myproject",
+			AURs:        []config.AUR{{}},
+		}, testctx.GitHubTokenType)
 		require.NoError(t, Pipe{}.Default(ctx))
 		require.Equal(t, config.AUR{
 			Name:                  "myproject-bin",
@@ -648,17 +628,14 @@ func TestDefault(t *testing.T) {
 	})
 
 	t.Run("name-without-bin-suffix", func(t *testing.T) {
-		ctx := &context.Context{
-			TokenType: context.TokenTypeGitHub,
-			Config: config.Project{
-				ProjectName: "myproject",
-				AURs: []config.AUR{
-					{
-						Name: "foo",
-					},
+		ctx := testctx.NewWithCfg(config.Project{
+			ProjectName: "myproject",
+			AURs: []config.AUR{
+				{
+					Name: "foo",
 				},
 			},
-		}
+		}, testctx.GitHubTokenType)
 		require.NoError(t, Pipe{}.Default(ctx))
 		require.Equal(t, config.AUR{
 			Name:                  "foo-bin",
@@ -676,18 +653,15 @@ func TestDefault(t *testing.T) {
 	})
 
 	t.Run("partial", func(t *testing.T) {
-		ctx := &context.Context{
-			TokenType: context.TokenTypeGitHub,
-			Config: config.Project{
-				ProjectName: "myproject",
-				AURs: []config.AUR{
-					{
-						Conflicts: []string{"somethingelse"},
-						Goamd64:   "v3",
-					},
+		ctx := testctx.NewWithCfg(config.Project{
+			ProjectName: "myproject",
+			AURs: []config.AUR{
+				{
+					Conflicts: []string{"somethingelse"},
+					Goamd64:   "v3",
 				},
 			},
-		}
+		}, testctx.GitHubTokenType)
 		require.NoError(t, Pipe{}.Default(ctx))
 		require.Equal(t, config.AUR{
 			Name:                  "myproject-bin",
@@ -707,11 +681,11 @@ func TestDefault(t *testing.T) {
 
 func TestSkip(t *testing.T) {
 	t.Run("skip", func(t *testing.T) {
-		require.True(t, Pipe{}.Skip(context.New(config.Project{})))
+		require.True(t, Pipe{}.Skip(testctx.New()))
 	})
 
 	t.Run("dont skip", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			AURs: []config.AUR{
 				{},
 			},
@@ -722,20 +696,31 @@ func TestSkip(t *testing.T) {
 
 func TestKeyPath(t *testing.T) {
 	t.Run("with valid path", func(t *testing.T) {
-		path := makeKey(t, keygen.Ed25519)
+		path := makeKey(t, keygen.Ed25519, nil)
 		result, err := keyPath(path)
 		require.NoError(t, err)
 		require.Equal(t, path, result)
 	})
 	t.Run("with invalid path", func(t *testing.T) {
 		result, err := keyPath("testdata/nope")
-		require.EqualError(t, err, `could not stat aur.private_key: stat testdata/nope: no such file or directory`)
+		require.ErrorIs(t, err, os.ErrNotExist)
 		require.Equal(t, "", result)
 	})
+
+	t.Run("with password protected key path", func(t *testing.T) {
+		path := makeKey(t, keygen.Ed25519, []byte("pwd"))
+		bts, err := os.ReadFile(path)
+		require.NoError(t, err)
+
+		result, err := keyPath(string(bts))
+		require.EqualError(t, err, "key is password-protected")
+		require.Empty(t, result)
+	})
+
 	t.Run("with key", func(t *testing.T) {
 		for _, algo := range []keygen.KeyType{keygen.Ed25519, keygen.RSA} {
 			t.Run(string(algo), func(t *testing.T) {
-				path := makeKey(t, algo)
+				path := makeKey(t, algo, nil)
 				bts, err := os.ReadFile(path)
 				require.NoError(t, err)
 
@@ -754,7 +739,7 @@ func TestKeyPath(t *testing.T) {
 		require.Equal(t, "", result)
 	})
 	t.Run("with invalid EOF", func(t *testing.T) {
-		path := makeKey(t, keygen.Ed25519)
+		path := makeKey(t, keygen.Ed25519, nil)
 		bts, err := os.ReadFile(path)
 		require.NoError(t, err)
 
@@ -771,7 +756,7 @@ func makeBareRepo(tb testing.TB) string {
 	tb.Helper()
 	dir := tb.TempDir()
 	_, err := git.Run(
-		context.New(config.Project{}),
+		testctx.New(),
 		"-C", dir,
 		"-c", "init.defaultBranch=master",
 		"init",
@@ -782,12 +767,12 @@ func makeBareRepo(tb testing.TB) string {
 	return dir
 }
 
-func makeKey(tb testing.TB, algo keygen.KeyType) string {
+func makeKey(tb testing.TB, algo keygen.KeyType, pass []byte) string {
 	tb.Helper()
 
 	dir := tb.TempDir()
 	filepath := filepath.Join(dir, "id")
-	_, err := keygen.NewWithWrite(filepath, nil, algo)
+	_, err := keygen.NewWithWrite(filepath, pass, algo)
 	require.NoError(tb, err)
 	return fmt.Sprintf("%s_%s", filepath, algo)
 }
@@ -795,7 +780,7 @@ func makeKey(tb testing.TB, algo keygen.KeyType) string {
 func requireEqualRepoFiles(tb testing.TB, folder, name, url string) {
 	tb.Helper()
 	dir := tb.TempDir()
-	_, err := git.Run(context.New(config.Project{}), "-C", dir, "clone", url, "repo")
+	_, err := git.Run(testctx.New(), "-C", dir, "clone", url, "repo")
 	require.NoError(tb, err)
 
 	for reponame, ext := range map[string]string{
